@@ -39,7 +39,7 @@ from googlecloudsdk.command_lib.iam import iam_util
 from googlecloudsdk.core import exceptions as core_exc
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
-from googlecloudsdk.core.credentials import http
+from googlecloudsdk.core.credentials import transports
 
 import six
 
@@ -241,7 +241,8 @@ class StorageClient(object):
     chunksize = self._GetChunkSize()
     download = transfer.Download.FromFile(
         local_path, chunksize=chunksize, overwrite=overwrite)
-    download.bytes_http = http.Http(response_encoding=None)
+    download.bytes_http = transports.GetApitoolsTransport(
+        response_encoding=None)
     get_req = self.messages.StorageObjectsGetRequest(
         bucket=source_obj_ref.bucket,
         object=source_obj_ref.object)
@@ -289,7 +290,8 @@ class StorageClient(object):
     data = io.BytesIO()
     chunksize = self._GetChunkSize()
     download = transfer.Download.FromStream(data, chunksize=chunksize)
-    download.bytes_http = http.Http(response_encoding=None)
+    download.bytes_http = transports.GetApitoolsTransport(
+        response_encoding=None)
     get_req = self.messages.StorageObjectsGetRequest(
         bucket=object_ref.bucket,
         object=object_ref.object)
@@ -331,7 +333,12 @@ class StorageClient(object):
   def CreateBucketIfNotExists(self, bucket, project=None, location=None):
     """Create a bucket if it does not already exist.
 
-    If it already exists and is owned by the creator, no problem.
+    If it already exists and is accessible by the current user, this method
+    returns.
+
+    Note that ownership is not checked by this method (an existing
+    bucket could belong to a malicious user so the client code needs to perform
+    ownership check if appropriate).
 
     Args:
       bucket: str, The storage bucket to be created.
@@ -340,8 +347,8 @@ class StorageClient(object):
       location: str, The bucket location/region.
 
     Raises:
-      api_exceptions.HttpError: If the bucket is owned by someone else
-          or is otherwise not able to be created.
+      api_exceptions.HttpError: If the bucket is not able to be created or is
+        not accessible due to permissions.
     """
     project = project or properties.VALUES.core.project.Get(required=True)
 
@@ -495,12 +502,33 @@ class StorageClient(object):
       member: Principal to add to the policy binding.
       role: Role to add to the policy binding.
 
+    Returns:
+      The new IAM Policy.
+    """
+    return self.AddIamPolicyBindings(bucket_ref, [(member, role)])
+
+  def AddIamPolicyBindings(self, bucket_ref, member_roles):
+    """Add IAM policy bindings on the specified bucket.
+
+    Does an atomic Read-Modify-Write, adding the member to the role.
+
+    Args:
+      bucket_ref: storage_util.BucketReference to the bucket with the policy.
+      member_roles: List of 2-tuples in the form [(member, role), ...].
+
     Returns:
       The new IAM Policy.
     """
     policy = self.GetIamPolicy(bucket_ref)
     policy.version = iam_util.MAX_LIBRARY_IAM_SUPPORTED_VERSION
 
-    iam_util.AddBindingToIamPolicy(self.messages.Policy.BindingsValueListEntry,
-                                   policy, member, role)
-    return self.SetIamPolicy(bucket_ref, policy)
+    policy_was_updated = False
+    for member, role in member_roles:
+      if iam_util.AddBindingToIamPolicy(
+          self.messages.Policy.BindingsValueListEntry, policy, member, role):
+        policy_was_updated = True
+
+    if policy_was_updated:
+      return self.SetIamPolicy(bucket_ref, policy)
+
+    return policy
