@@ -255,7 +255,7 @@ exports.full_extensions_map = {
   {"3gp", "video/3gpp"},
   {"3gp2", "video/3gpp2"},
   {"3gpp", "video/3gpp"},
-  {"7z", "application/x-7z-compressed"},
+  {"7z", {"application/x-7z-compressed", "application/7z"}},
   {"aa", "audio/audible"},
   {"AAC", "audio/aac"},
   {"aaf", "application/octet-stream"},
@@ -309,7 +309,7 @@ exports.full_extensions_map = {
   {"bas", "text/plain"},
   {"bcpio", "application/x-bcpio"},
   {"bin", "application/octet-stream"},
-  {"bmp", "image/bmp"},
+  {"bmp", {"image/bmp", "image/x-ms-bmp"}},
   {"c", "text/plain"},
   {"cab", "application/octet-stream"},
   {"caf", "audio/x-caf"},
@@ -969,4 +969,4 @@ exports.reversed_extensions_map = {
   ["video/x-msvideo"] = "avi",
 }
 
-return exports
\ No newline at end of file
+return exports
